@@ -1,10 +1,6 @@
 #!/usr/bin/env python
 # -*- encoding: utf-8 -*-
 
-import sys
-import os
-sys.path.append(os.path.dirname(__file__))
-
 from pathlib import Path
 import pickle
 import math
